########################
Amazon Braket Python SDK
########################

The Amazon Braket Python SDK is an open source library to design and build quantum circuits, 
submit them to Amazon Braket devices as quantum tasks, and monitor their execution.

This documentation provides information about the Amazon Braket Python SDK library. The project
homepage is in Github https://github.com/amazon-braket/amazon-braket-sdk-python. The project
includes SDK source, installation instructions, and other information.

***************
Getting Started
***************

.. toctree::
    :maxdepth: 2

    getting-started


********
Examples
********

Explore Amazon Braket examples.

.. toctree::
    :maxdepth: 3

    examples.rst
   

***************
Python SDK APIs
***************

The Amazon Braket Python SDK APIs:

.. toctree::
    :maxdepth: 2
    
    _apidoc/modules

